define(['testsuite/qunit', 'jquery', 'ep/uri', '$ready!'], function (QUnit, $, ep) {

	QUnit.module("ep/uri");

	QUnit.asyncTest("ep/uri", function() {

		QUnit.deepEqual(
			ep.uriSegment('http://www.epages.com/de/images/example.jpg?size=xl#center'),
			{"href":"http://www.epages.com/de/images/example.jpg?size=xl#center","protocol":"http","host":"www.epages.com","path":"de/images/example.jpg","query":"?size=xl","anchor":"#center","parameters":{"size":"xl"}},
			"ep.uriSegment('http://www.epages.com/de/images/example.jpg?size=xl#center')"
		);

		QUnit.equal(
			ep.uriSegment({"href":"http://www.epages.com/de/images/example.jpg?size=xl#center","protocol":"http","host":"www.epages.com","path":"de/images/example.jpg","query":"?size=xl","anchor":"#center","parameters":{"size":"xl"}}),
			'http://www.epages.com/de/images/example.jpg?size=xl#center',
			'ep.uriSegment({"href":"http://www.epages.com/de/images/example.jpg?size=xl#center","protocol":"http","host":"www.epages.com","path":"de/images/example.jpg","query":"?size=xl","anchor":"#center","parameters":{"size":"xl"}})'
		);

		QUnit.ok(
			ep.uriIsAbsolute('http://www.epages.com/de/images/example.jpg?size=xl#center'),
			"ep.uriIsAbsolute('http://www.epages.com/de/images/example.jpg?size=xl#center')"
		);

		QUnit.ok(
			!ep.uriIsAbsolute('epages.com/de/images/example.jpg?size=xl#center'),
			"!ep.uriIsAbsolute('epages.com/de/images/example.jpg?size=xl#center')"
		);

		QUnit.equal(
			ep.uriToRelative( 'http://www.epages.com/de/images/example.jpg?size=xl#center', 'http://www.epages.com/de/' ),
			'images/example.jpg?size=xl#center',
			"ep.uriToRelative( 'http://www.epages.com/de/images/example.jpg?size=xl#center', 'http://www.epages.com/de/' )"
		);

		QUnit.equal(
			ep.uriToRelative( 'http://www.epages.com/de/images/example.jpg?size=xl#center', 'http://www.epages.com/de' ),
			'images/example.jpg?size=xl#center',
			"ep.uriToRelative( 'http://www.epages.com/de/images/example.jpg?size=xl#center', 'http://www.epages.com/de' )"
		);

		QUnit.equal(
			ep.uriToRelative( 'de/images/example.jpg?size=xl#center', 'http://www.epages.com/de/' ),
			'images/example.jpg?size=xl#center',
			"ep.uriToRelative( 'de/images/example.jpg?size=xl#center', 'http://www.epages.com/de/' )"
		);

		QUnit.equal(
			ep.uriToRelative( 'de/images/example.jpg?size=xl#center', 'http://www.epages.com/de' ),
			'images/example.jpg?size=xl#center',
			"ep.uriToRelative( 'de/images/example.jpg?size=xl#center', 'http://www.epages.com/de' )"
		);

		QUnit.equal(
			ep.uriToRelative( '/de/images/example.jpg?size=xl#center', 'http://www.epages.com/de' ),
			'images/example.jpg?size=xl#center',
			"ep.uriToRelative( '/de/images/example.jpg?size=xl#center', 'http://www.epages.com/de' )"
		);

		QUnit.equal(
			ep.uriToRelative( 'de/source/images/example.jpg?size=xl#center', 'http://www.epages.com/de/source/' ),
			'images/example.jpg?size=xl#center',
			"ep.uriToRelative( 'de/source/images/example.jpg?size=xl#center', 'http://www.epages.com/de/source/' )"
		);

		QUnit.equal(
			ep.uriToRelative( '/de/source/images/example.jpg?size=xl#center', 'http://www.epages.com/de/source' ),
			'images/example.jpg?size=xl#center',
			"ep.uriToRelative( '/de/source/images/example.jpg?size=xl#center', 'http://www.epages.com/de/source' )"
		);

		QUnit.equal(
			ep.uriToRelative( 'de/source/images/example.jpg?size=xl#center', 'http://www.epages.com/de/source' ),
			'images/example.jpg?size=xl#center',
			"ep.uriToRelative( 'de/source/images/example.jpg?size=xl#center', 'http://www.epages.com/de/source' )"
		);

		QUnit.equal(
			ep.uriToAbsolute( '/de/source/images/example.jpg?size=xl#center', 'http://www.epages.com/de/source' ),
			'http://www.epages.com/de/source/images/example.jpg?size=xl#center',
			"ep.uriToRelative( '/de/source/images/example.jpg?size=xl#center', 'http://www.epages.com/de/source' )"
		);

		QUnit.equal(
			ep.uriToAbsolute( 'de/source/images/example.jpg?size=xl#center', 'http://www.epages.com/de/source' ),
			'http://www.epages.com/de/source/images/example.jpg?size=xl#center',
			"ep.uriToRelative( 'de/source/images/example.jpg?size=xl#center', 'http://www.epages.com/de/source' )"
		);

		start();
	});

});